Introduction
============

.. autosummary::
    :toctree: _autosummary
    :template: module_custom.rst
    :recursive:

    optika


References
==========

.. bibliography::

|


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
